@@ -8,12 +8,26 @@ class Rsync():
 	def option(self, opt):
 		self.opt.append(opt)
 		return(self)
+	def verbose(self):
+		self.opt.append('--verbose')
+		return(self)
+	def quiet(self):
+		self.opt.append('--quiet')
+		return(self)
 	def delete(self):
 		self.opt.append('--delete')
 		return(self)
+	def update(self):
+		self.opt.append('--update')
+		return(self)
 	def backup(self, dir):
 		self.opt.append('--backup --backup-dir='+dir)
 		return(self)
+	def compress(self, num = None):
+		self.opt.append("--compress")
+		if num :
+			self.opt.append("--compress-level={num}".format(num=num))
+		return(self)
 	def logfile(self, log):
 		self.opt.append('--log-file='+log)
 		return(self)
@@ -42,7 +56,8 @@ class Rsync():
 		self.cmd['dest'] = dest
 		return(self)
 	def execute(self):
-		os.system(self.__to_string())
+		rev = os.system(self.__to_string())
+		return(rev)
 	def __to_string(self):
 		return('rsync '+' '.join(self.opt)+' '+self.cmd['src']+' '+ self.cmd['dest'])
 	def debug(self):
